# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['pyvarium', 'pyvarium.cli', 'pyvarium.installers', 'pyvarium.util']

package_data = \
{'': ['*']}

install_requires = \
['Jinja2>=3.0.3,<4.0.0',
 'dynaconf>=3.1.4,<4.0.0',
 'loguru>=0.5.3,<0.6.0',
 'pyaml>=21.8.3,<22.0.0',
 'pydantic>=1.9.1,<2.0.0',
 'rich>=10.7.0,<11.0.0',
 'rtoml>=0.8.0,<0.9.0',
 'typer[all]>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['pyvarium = pyvarium.cli:app']}

setup_kwargs = {
    'name': 'pyvarium',
    'version': '0.2.0',
    'description': 'Tool for managing mixed Spack and pip packages',
    'long_description': '# Pyvarium\n\n[![Tests](https://github.com/European-XFEL/pyvarium/actions/workflows/tests.yml/badge.svg)](https://github.com/European-XFEL/pyvarium/actions/workflows/tests.yml) | [![Docs](https://github.com/European-XFEL/pyvarium/actions/workflows/docs.yml/badge.svg)](https://european-xfel.github.io/pyvarium/)\n\nPyvarium is a tool designed to help create environments which are managed by [Spack](github.com/spack/spack/) and a pure python environment manager like [Pipenv](https://pipenv.pypa.io/en/latest/) or [Poetry](https://github.com/python-poetry/poetry).\n\nIt aims to help tackle the problem of long term reproducibility and portability of software environments, especially in the area of scientific HPC, by combining the ability of Spack to compile arbitrary software (as long as a package Spack package has been written for it) and flexibility of python environments.\n\n## Installation\n\nSimplest installation is with [pipx](https://github.com/pypa/pipx):\n\n```shell\npipx install pyvarium\n```\n\nNote that Pyvarium is designed to **manage** Spack and python environments, so an existing spack installation as well as a supported backend (e.g. pipenv) is required for Pyvarium to run.\n\n## Quick Start\n\n```shell\n$ pyvarium --help\nUsage: pyvarium [OPTIONS] COMMAND [ARGS]...\n\nDeploy mixed computational environments with dependencies and packages provided by Spack and Pipenv\n\nOptions:\n  --log-level [TRACE|DEBUG|INFO|WARNING|ERROR|CRITICAL]\n                                  Pick which level of output to show\n                                  [default: INFO]\n\n  -v, --verbose                   [default: 0]\n  --install-completion            Install completion for the current shell.\n  --show-completion               Show completion for the current shell, to\n                                  copy it or customize the installation.\n\n  --help                          Show this message and exit.\n\nCommands:\n  add                                Add packages via spack or pipenv.\n  config                             Modify user settings for pyvarium.\n  install                            Concretize and install an existing environment.\n  modulegen                          Generate modulefile to load the environment.\n  new                                Create a new combined Spack and Pipenv environment.\n  sync                               Sync Spack-managed packages with Pipenv.\n```\n\nTo create a new environment:\n\n```\n$ pyvarium new ./environment-demo\n```\n\nThis creates a new directory `./environment-demo` which has Pipenv (`Pipfile`, `Pipfile.lock`) and Spack (`spack.yaml`, `spack.lock`) environment specification files in it. By default these will only specify `python` and `pip` as requirements.\n\nIn general setting up the environment should be done in a specific order, you must install any python packages which have **external dependencies** via Spack **first**, then install any required pure python packages via pipenv afterwards. Otherwise python packages with external dependencies will use their bundled binaries instead of whatever is provided via spack.\n\n\nInstallation of dependencies can be done with `pyvarium add {spack,pipenv}`, this command is a wrapper around the respective add/install commands which ensures that the dependencies specified by both programs remain in sync:\n\n```shell\n$ pyvarium add spack py-numpy py-h5py\n$ pyvarium add pipenv extra-data\n```\n\nThe above commands would install numpy and h5py via spack, compiling dependencies along the way, sync these packages with `Pipfile` so that pipenv is aware of what is already within the environment, and then install any specified packages via pipenv.\n\nThe environment can be activated as a normal venv with `source .venv/bin/activate`, or a module file can be created for it with with `pyvarium modulegen`.\n\n## Usage\n\n```shell\nUsage: pyvarium [OPTIONS] COMMAND [ARGS]...\n\n Deploy mixed computational environments with dependencies and packages provided by Spack and Pipenv\n\n╭─ Options ──────────────────────────────────────────────────────────────────────────────────────────╮\n│ --log-level                 [TRACE|DEBUG|INFO|WARNING|ERROR|C  Pick which level of output to show  │\n│                             RITICAL]                           [default: LogLevel.info]            │\n│ --install-completion                                           Install completion for the current  │\n│                                                                shell.                              │\n│ --show-completion                                              Show completion for the current     │\n│                                                                shell, to copy it or customize the  │\n│                                                                installation.                       │\n│ --help                                                         Show this message and exit.         │\n╰────────────────────────────────────────────────────────────────────────────────────────────────────╯\n╭─ Commands ─────────────────────────────────────────────────────────────────────────────────────────╮\n│ add              Add packages via spack or pipenv.                                                 │\n│ config           Modify user settings for pyvarium.                                                │\n│ install          Concretize and install an existing environment.                                   │\n│ modulegen        Generate modulefile to load the environment.                                      │\n│ new              Create a new combined Spack and Pipenv environment.                               │\n│ sync             Sync Spack-managed packages with Pipenv.                                          │\n╰────────────────────────────────────────────────────────────────────────────────────────────────────╯\n```\n\n### `config`\n\n```shell\nUsage: pyvarium config [OPTIONS] COMMAND [ARGS]...\n\n Modify user settings for pyvarium.\n\n╭─ Options ──────────────────────────────────────────────────────────────────────────────────────────╮\n│ --help          Show this message and exit.                                                        │\n╰────────────────────────────────────────────────────────────────────────────────────────────────────╯\n╭─ Commands ─────────────────────────────────────────────────────────────────────────────────────────╮\n│ info   Show information about the current configuration.                                           │\n│ list   List configuration.                                                                         │\n│ set    Set a key value pair for configuration, e.g. `pyvarium set poetry_exec                      │\n│        /opt/poetry/bin/poetry`.                                                                    │\n│ unset  Remove a custom settings from configuration (this reverts to the default, to disable a      │\n│        default set it to an empty string, e.g. `pyvarium set poetry_exec ""`).                     │\n╰────────────────────────────────────────────────────────────────────────────────────────────────────╯\n```\n\n`info` will show the absolute location of the configuration files being used, in the order they are loaded.\n\n`list` shows the current configuration.\n\n`set` can be used to set a key-value pair, and `unset` can be used to remove one. Setting and unsetting configurations can be performed at different scopes: `local` for the local directory (e.g. creating a `pyvarium.toml` file), `user` for the user configuration (`~/.config/pyvarium/settings.toml`), and `builtin` to modify the default configuration within the package.\n\nThe configuration is a TOML file containing the paths to the executables to be used by pyvarium, for example:\n\n```toml\npipenv = "/home/roscar/.local/bin/pipenv"\npipx = "/home/roscar/.local/bin/pipx"\npoetry = "/sbin/poetry"\nspack = "/opt/spack"\n```\n\nBy default, if an entry is not present in the file for one of these programs, it is automatically set to the path of `which $program`.\n\n### `new`\n\n```shell\nUsage: pyvarium new [OPTIONS] PATH COMMAND [ARGS]...\n\n Create a new combined Spack and Pipenv environment.\n\n╭─ Arguments ────────────────────────────────────────────────────────────────────────────────────────╮\n│ *    path      DIRECTORY  [default: None] [required]                                               │\n╰────────────────────────────────────────────────────────────────────────────────────────────────────╯\n╭─ Options ──────────────────────────────────────────────────────────────────────────────────────────╮\n│ --help          Show this message and exit.                                                        │\n╰────────────────────────────────────────────────────────────────────────────────────────────────────╯\n```\n\n### `add`\n\n```shell\nUsage: pyvarium add [OPTIONS] COMMAND [ARGS]...\n\n Add packages via spack or pipenv.\n\n╭─ Options ──────────────────────────────────────────────────────────────────────────────────────────╮\n│ --help          Show this message and exit.                                                        │\n╰────────────────────────────────────────────────────────────────────────────────────────────────────╯\n╭─ Commands ─────────────────────────────────────────────────────────────────────────────────────────╮\n│ pipenv                                                                                             │\n│ spack                                                                                              │\n╰────────────────────────────────────────────────────────────────────────────────────────────────────╯\n```\n',
    'author': 'Robert Rosca',
    'author_email': '32569096+RobertRosca@users.noreply.github.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0.0',
}


setup(**setup_kwargs)
